@@ -1,3 +1,7 @@
+# Copyright (C) 2014 New York University
+# This file is part of ReproZip which is released under the Revised BSD License
+# See file LICENSE for full license details.
+
 from __future__ import unicode_literals
 
 import argparse
@@ -8,7 +12,7 @@ from pkg_resources import iter_entry_points
 import sys
 
 
-__version__ = '0.2'
+__version__ = '0.2.1'
 
 
 def main():
@@ -27,7 +31,7 @@ def main():
 
     # General options
     options = argparse.ArgumentParser(add_help=False)
-    options.add_argument('-v', '--verbose', action='count', default=0,
+    options.add_argument('-v', '--verbose', action='count', default=1,
                          dest='verbosity',
                          help="augments verbosity level")
 
@@ -43,7 +47,7 @@ def main():
         setup_function(subparsers=subparsers, general_options=options)
 
     args = parser.parse_args()
-    levels = [logging.WARNING, logging.INFO, logging.DEBUG]
-    logging.basicConfig(level=levels[min(args.verbosity, 2)])
+    levels = [logging.CRITICAL, logging.WARNING, logging.INFO, logging.DEBUG]
+    logging.basicConfig(level=levels[min(args.verbosity, 3)])
     args.func(args)
     sys.exit(0)
